@@ -1,5 +1,5 @@
 from typing import Dict, Any, List, Optional
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from pytz import timezone
 from databricks.sdk import WorkspaceClient
 from pyspark.sql import SparkSession
@@ -10,6 +10,7 @@ import os
 import logging
 import re
 import pandas as pd
+from email_notification import email_notification
 from .utils import (
     execute_run_databricks,
     execute_run_postgres,
@@ -813,77 +814,129 @@ class RuleManager:
 
 
     def business_rule_check(self) -> Dict[str, List[Dict[str, Any]]]:
+        BATCH_ID = datetime.utcnow().strftime("%Y%m%d%H%M%S%f")
         results = []
-        if self.template.get("RULE_CATEGORY_NAME") == 'BUSINESS_RULE_CHECK':
-            for idx, rule in enumerate(self.rules.get("RULES", [])):
-                
-                rule = {**self.template, **rule}
-                rule = self.set_system_variables(rule)
+        current_time_et = datetime.now(timezone("US/Eastern")).strftime("%Y-%m-%d %H:%M:%S %Z")
 
-                rule = self.set_business_rule_check_templates(rule)
-                rule = self.set_bookmark_value(rule)
-                rule = self.process_fail_sql(rule)
-                rule = self.process_pass_sql(rule)
-                rule = self.set_business_rule_check_final_queries(rule)
-                rule = self.exec_business_rule_check_final_queries(rule)
+        # Read config-driven email values
+        email_enabled = self.template.get("Email_Notification", False)
+        recipient_email = self.template.get("TEAM_EMAIL")
+        email_api_url = self.template.get("URL")
+        env = self.template.get("ENV", "DEV")
 
-                self.rules["RULES"][idx] = rule
-                self.logger.info(json.dumps(rule, indent=2))
+        try:
+            if self.template.get("RULE_CATEGORY_NAME") == 'BUSINESS_RULE_CHECK':
+                for idx, rule in enumerate(self.rules.get("RULES", [])):
+                    rule = {**self.template, **rule}
+                    rule['BATCH_ID'] = BATCH_ID
+                    rule = self.set_system_variables(rule)
+                    rule = self.set_business_rule_check_templates(rule)
+                    rule = self.set_bookmark_value(rule)
+                    rule = self.process_fail_sql(rule)
+                    rule = self.process_pass_sql(rule)
+                    rule = self.set_business_rule_check_final_queries(rule)
+                    rule = self.exec_business_rule_check_final_queries(rule)
 
-                rule_name = rule.get('RULE_NAME', 'Unknown')
-                rule_id = rule.get('RULE_ID', 'Unknown')
+                    self.rules["RULES"][idx] = rule
+                    self.logger.info(json.dumps(rule, indent=2))
 
-                results.append({
-                "RULE_ID": rule_id,
-                "RULE_NAME": rule_name,
-                "DOMAIN_NAME": rule.get('DOMAIN_NAME'),
-                "TABLES_CHECKED": rule.get('TABLES_CHECKED'),
-                "TEAM_NAME": rule.get('TEAM_NAME'),
-                "SEVERITY": rule.get('SEVERITY'),
-                "RULE_CATEGORY": rule.get('RULE_CATEGORY'),
-                "STATUS": rule.get('STATUS'),
-                "QUERY": rule.get('FAILED_QUERY'),
-                "FAIL_RECORD_COUNT": rule.get('FAIL_RECORD_COUNT'),
-                "PASS_RECORD_COUNT": rule.get('PASS_RECORD_COUNT'),
-                "COMMENTS": rule.get('COMMENTS'),
-                "REMARKS": rule.get('REMARKS'),
-                "TIME": rule.get('TIME', datetime.now(timezone('UTC')).isoformat())
-                })
+                    rule_name = rule.get('RULE_NAME', 'Unknown')
+                    rule_id = rule.get('RULE_ID', 'Unknown')
 
-                if rule.get('STOP_ON_FAIL_STATUS')=='TRUE':  # for checking as per user input
-                    self.logger.warning(f"Rule {rule_name} (ID: {rule_id}) failed with STOP_ON_FAIL_STATUS=TRUE. Stopping execution of remaining rules.")
-                     
-                    if not rule.get('STATUS'): # for checking as per rule status
-                        self.logger.warning(f"Rule {rule_name} (ID: {rule_id}) failed STATUS is FALSE.")         
+                    results.append({
+                        "RULE_ID": rule_id,
+                        "RULE_NAME": rule_name,
+                        "DOMAIN_NAME": rule.get('DOMAIN_NAME'),
+                        "TABLES_CHECKED": rule.get('TABLES_CHECKED'),
+                        "TEAM_NAME": rule.get('TEAM_NAME'),
+                        "SEVERITY": rule.get('SEVERITY'),
+                        "RULE_CATEGORY": rule.get('RULE_CATEGORY'),
+                        "STATUS": rule.get('STATUS'),
+                        "FAIL_RECORD_COUNT": rule.get('FAIL_RECORD_COUNT'),
+                        "PASS_RECORD_COUNT": rule.get('PASS_RECORD_COUNT'),
+                        "COMMENTS": rule.get('COMMENTS'),
+                        "TIME": rule.get('TIME', datetime.now(timezone('UTC')).isoformat())
+                    })
+
+                    if rule.get('STOP_ON_FAIL_STATUS') == 'TRUE' and not rule.get('STATUS'):
+                        self.logger.warning(f"Rule {rule_name} (ID: {rule_id}) failed. Sending failure email and stopping.")
+
+                        if email_enabled:
+                            email_notification(
+                                current_time_et=current_time_et,
+                                recipient_name=recipient_email,
+                                subject=f"Rule {rule_name} Failed",
+                                env=env,
+                                body_part=rule.get('COMMENTS', 'Rule failed'),
+                                footer=f"Rule ID: {rule_id}",
+                                is_failure=True,
+                                file_name=rule.get("FILE_NAME"),
+                                url=email_api_url
+                            )
                         break
-                  
-        elif self.template.get("RULE_CATEGORY_NAME") == 'DATA_PARITY_CHECK':    
-            for idx, rule in enumerate(self.rules.get("RULES", [])):
-                rule = {**self.template, **rule}
-                rule = self.set_system_variables(rule)
 
-                if rule.get("LOAD_FILES", False):
-                    self.logger.info(f"Loading files for rule: {rule['RULE_NAME']}")
-                    self.loader(rule)  
+            elif self.template.get("RULE_CATEGORY_NAME") == 'DATA_PARITY_CHECK':
+                for idx, rule in enumerate(self.rules.get("RULES", [])):
+                    rule = {**self.template, **rule}
+                    rule['BATCH_ID'] = BATCH_ID
+                    rule = self.set_system_variables(rule)
 
-                rule = self.set_data_parity_check_templates(rule)
-                rule = self.set_bookmark_value(rule)
-                rule = self.set_data_parity_check_final_queries(rule)
-                rule = self.exec_data_parity_check_final_queries(rule)
+                    if rule.get("LOAD_FILES", False):
+                        self.logger.info(f"Loading files for rule: {rule['RULE_NAME']}")
+                        self.loader(rule)
 
-                self.rules["RULES"][idx] = rule
-                
-                if rule.get("DROP_TEMP_TABLES", False):
-                    self.logger.info(f"Dropping temp tables for rule: {rule['RULE_NAME']}")
-                    self.drop_temp_tables(rule)
+                    rule = self.set_data_parity_check_templates(rule)
+                    rule = self.set_bookmark_value(rule)
+                    rule = self.set_data_parity_check_final_queries(rule)
+                    rule = self.exec_data_parity_check_final_queries(rule)
 
-                if 'summary_report_df' in rule and not rule['summary_report_df'].empty:
-                    print("SUMMARY REPORT:")
-                    print(rule['summary_report_df'].to_string())
+                    self.rules["RULES"][idx] = rule
 
-                self.logger.info(f"Rule {idx + 1} processed successfully")
-                results.append(rule)
+                    if rule.get("DROP_TEMP_TABLES", False):
+                        self.logger.info(f"Dropping temp tables for rule: {rule['RULE_NAME']}")
+                        self.drop_temp_tables(rule)
 
+                    if 'summary_report_df' in rule and not rule['summary_report_df'].empty:
+                        if email_enabled:
+                            email_notification(
+                                current_time_et=current_time_et,
+                                recipient_name=recipient_email,
+                                subject=f"{rule.get('RULE_NAME')} Summary Report",
+                                env=env,
+                                body_part="failed records summary",
+                                df=rule['summary_report_df'],
+                                footer=f"Rule ID: {rule.get('RULE_ID')}",
+                                url=email_api_url
+                            )
 
-        print(json.dumps({"RULES": results}, indent=2))
-        return results
\ No newline at end of file
+                    self.logger.info(f"Rule {idx + 1} processed successfully")
+                    results.append(rule)
+
+            # 📤 Send final summary email
+            if email_enabled:
+                email_notification(
+                    current_time_et=current_time_et,
+                    recipient_name=recipient_email,
+                    subject="Business Rule Check Summary",
+                    env=env,
+                    body_part=f"{len(results)} rules processed successfully",
+                    footer=f"BATCH_ID: {BATCH_ID}",
+                    url=email_api_url
+                )
+
+            print(json.dumps({ "BATCH_ID": BATCH_ID, "RULES": results }, indent=2))
+            return results
+
+        except Exception as e:
+            self.logger.error(f"Critical Error in business_rule_check: {str(e)}")
+            if email_enabled:
+                email_notification(
+                    current_time_et=current_time_et,
+                    recipient_name=recipient_email,
+                    subject="Business Rule Check - Execution Error",
+                    env=env,
+                    body_part=str(e),
+                    is_failure=True,
+                    url=email_api_url
+                )
+            raise
\ No newline at end of file
