@@ -1,4 +1,5 @@
 INSERT INTO <DATABASE_NAME>.pybrv_meta.pybrv_business_rule_check_result (
+    batch_id,
     unique_rule_identifier,    
     execution_id,              
     team_name,                 
@@ -22,6 +23,7 @@ INSERT INTO <DATABASE_NAME>.pybrv_meta.pybrv_business_rule_check_result (
     last_modified_ts
 )
 SELECT
+    <BATCH_ID>,
     <UNIQUE_RULE_IDENTIFIER>,
     <EXECUTION_ID>,
     '<TEAM_NAME>',
